<?php 

/*	Implementation of hook_form_alter
 * 1. Alter the Platform nodes to add in controls for default resource settings <In Development>
 * 2. Alter the Server nodes to add in controls for default resource settings <In Development>
 * 3. Alter the Site nodes to add in controls / display of the resource settings on a site level <In Development>
 * 4. Alter the Client node to allow resource management on a per client level 
 */
function hostmaster_resources_form_alter(&$form, &$form_alter, $form_id ){
	
	//drupal_set_message($form_id);
	if($form_id == 'site_node_form'){
		$form['hostmaster_resources'] = array(
			'#type' => 'fieldset',
			'#collapsible' => TRUE,
			'#collapsed' => TRUE,
			'#title' => t('Site Resource Settings')
		);
		$form['hostmaster_resources']['max_database'] = array(
			'#type' => 'textfield',
			'#title' => t('Max Database Size'),
			'#description' => t('Set the maximum database size a site should have.'),
			'#default_value' => $form['#node']->max_database
		);
		$form['hostmaster_resources']['max_files'] = array(
			'#type' => 'textfield',
			'#title' => t('Max Filesize'),
			'#description' => t('Set the Maximum filesize for a sites folder.'),
			'#default_value' => $form['#node']->max_files
		);
		$form['hostmaster_resources']['bandwidth'] = array(
			'#type' => 'fieldset',
			'#title' => t('Bandwidth Settings'),
			'#collapsed' => FALSE,
			'#collapsibe' => FALSE
		);
		$form['hostmaster_resources']['bandwidth']['bandwidth_quota'] = array(
			'#type' => 'textfield',
			'#title' => t('Bandwidth Quota'),
			'#description' => t('Set a limit to a sites bandwidth over a period of time.'),
			'#default_value' => $form['#node']->bandwidth_quota
		);
		$form['hostmaster_resources']['bandwidth']['bandwidth_term_count'] = array(
			'#type' => 'textfield',
			'#title' => t('Term Length'),
			'#default_value' => $form['#node']->bandwidth_term_count			
		);
		$form['hostmaster_resources']['bandwidth']['bandwidth_term_type'] = array(
			'#type' => 'select',
			'#title' => t('Length Type'),
			'#options' => array(0 => 'hours', 1 => 'weeks', 2 => 'months', 3 => 'years'),
			'#default_value' => $form['#node']->bandwidth_term_type
		);
		$form['hostmaster_resources']['bandwidth_throttle'] = array(
			'#type' => 'textfield',
			'#title' => t('Bandwidth Throttle'),
			'#description' => t('Set the Maximum bandwidth that this site will use( MB ).'),
			'#default_value' => $form['#node']->bandwidth_throttle
		);
		
		// NEED TO ADD VALIDATION FUNCTION TO MAKE SURE THAT IT DOES NOT VIOLATE MAX FOR CLIENT, PLATFORM, OR SERVER LEVELS
				
	} 	
}


/*
 * Implementation of Hook_nodeapi
 */
function hostmaster_resources_nodeapi( &$node, $op, $a3 = NULL, $a4 = NULL ){
  
  if($node->type == 'site' ){
		// code for management of sites goes here
		switch($op){
			
			case 'view':
				if($node->type == 'site'){
					$obj['url'] = $node->title;
					$node->content['info']['resources'] = array(
				      '#type' => 'fieldset',
				      '#title' => t('Resources'),
					  '#weight' => 10
				    );
					
				    // Database use for a site
				    $node->content['info']['resources']['max_database'] = array(
				      '#type' => 'item',
				      '#title' => t('Max Database'),
				      '#value' => $node->max_database,
					  '#parent' => 'resources'
				    );
					$node->content['info']['resources']['database_size'] = array(
						'#type' => 'item',
						'#title' => t('Current DB Size'),
						'#value' => _sizeFormat(_resource_db_useage($obj))
					);
					// File Useage on a site
					$node->content['info']['resources']['max_files'] = array(
				    	'#type' => 'item',
				    	'#title' => t('Max Filespace'),
				    	'#value' => $node->max_files 
				    );
				    $used_files = _resource_file_useage($obj);
				    $node->content['info']['resources']['current_files'] = array(
				    	'#type' => 'item',
				    	'#title' => t('Used Filespace'),
				    	'#value' => _sizeFormat( $used_files['size'] ) 
				    );
				    
				    // Bandwidth Useage on a site
				    $node->content['info']['resources']['bandwidth_quota'] = array(
				    	'#type' => 'item',
				    	'#title' => t('Bandwidth Quota'),
				    	'#value' => $node->bandwidth_quota,
				    	'#weight' => -10
				    );
				    
				    $node->content['info']['resources']['bandwidth_use'] = array(
				    	'#type' => 'item',
				    	'#title' => t('Bandwidth Used'),
				    	'#value' => _resource_bandwidth_useage($obj),
				    	'#weight' => -9
				    );
					
				}
			break;
			
			case 'load':
				
				$hostmaster_resources = db_fetch_object( db_query('SELECT * FROM {hostmaster_resources_site} WHERE nid = %d AND vid = %d', $node->nid, $node->vid ) );
				$node->max_database = $hostmaster_resources->max_database;
				$node->max_files = $hostmaster_resources->max_files;
				$node->bandwidth_quota = $hostmaster_resources->bandwidth_quota;
				$node->bandwidth_term_count = $hostmaster_resources->bandwidth_term_count;
				$node->bandwidth_term_type = $hostmaster_resources->bandwidth_term_type;
				$node->over_limit_action = $hostmaster_resources->over_limit_action;
				$node->bandwidth_throttle = $hostmaster_resources->bandwidth_throttle;
				
			break;
			
			case 'insert':
				db_query('INSERT INTO {hostmaster_resources_site} ( nid, vid, max_database, max_files, bandwidth_quota, bandwidth_term_count, bandwidth_term_type, over_limit_action, bandwidth_throttle  ) VALUES 
				( %d, %d, "%s", "%s", "%s", %d, %d, %d, "%s" )', $node->nid, $node->vid, $node->max_database, $node->max_files, $node->bandwidth_quota, $node->bandwidth_term_count, $node->bandwidth_term_type, $node->over_limit_action, $node->bandwidth_throttle );
			break;
			
			case 'delete':
				db_query('DELETE FROM {hostmaster_resources_site} WHERE nid = %d', $node->nid);
			break;
			
			case 'delete_revision':
				db_query('DELETE FROM {hostmaster_resources_site} WHERE vid = %d', $node->vid);
			break;
			
			case 'update':
				
				if($node->revision){
					db_query('INSERT INTO {hostmaster_resources_site} ( nid, vid, max_database, max_files, bandwidth_quota, bandwidth_term_count, bandwidth_term_type, over_limit_action, bandwidth_throttle  ) VALUES 
				( %d, %d, "%s", "%s", "%s", %d, %d, %d, "%s" )', $node->nid, $node->vid, $node->max_database, $node->max_files, $node->bandwidth_quota, $node->bandwidth_term_count, $node->bandwidth_term_type, $node->over_limit_action, $node->bandwidth_throttle );
				} else {
					db_query( 'UPDATE {hostmaster_resources_site} SET max_database = "%s", max_files = "%s", bandwidth_quota = "%s", bandwidth_term_count = %d, bandwidth_term_type = %d, over_limit_action = %d, bandwidth_throttle = "%s" WHERE vid = %d',
					$node->max_database, $node->max_files, $node->bandwidth_quota, $node->bandwidth_term_count, $node->bandwidth_term_type, $node->over_limit_action, $node->bandwidth_throttle, $node->vid 
					);
				}
			break;
		}
		
	} 
}


?>